@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2014   Lukas F. Reichlin
+## Copyright (C) 2009-2015   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -20,7 +20,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: October 2009
-## Version: 0.3
+## Version: 0.4
 
 function val = __get__ (sys, prop)
 
@@ -31,7 +31,7 @@ function val = __get__ (sys, prop)
     case "den"
       val = cellfun (@get, sys.den, "uniformoutput", false);
 
-    case {"tfvar", "variable", "var"}
+    case {"tfvar", "variable"}
       val = sys.tfvar;
 
     case "inv"
